-
Qu’est-ce que Mariabackup?
-
Sauvegarder et restaurer MariaDB avec Mariabackup
-
Sauvegarde et restauration de MariaDB avec mysqldump
-
Sauvegarde et restauration de MariaDB avec une solution de sauvegarde de bases de données

MariaDB est un système de gestion de bases de données relationnelles (SGBDR) open source très populaire, conçu pour être un remplacement direct de MySQL. Il a été créé par les développeurs d’origine de MySQL après que des inquiétudes se soient exprimées concernant son acquisition par Oracle Corporation.
MariaDB présente une forte compatibilité avec MySQL et offre une parité binaire identique au niveau des bibliothèques, tout en correspondant exactement aux API et aux commandes MySQL. Cela facilite la migration de la base de données de MySQL vers MariaDB.
Si vous utilisez MariaDB, il est essentiel de savoir comment effectuer des sauvegardes MariaDB et les restaurer. Dans cet article, vous apprendrez à sauvegarder et restaurer MariaDB à l’aide de Mariabackup ainsi que par deux autres méthodes. Vous vous demandez peut-être alors : qu’est-ce que Mariabackup ?
Qu’est-ce que Mariabackup?
Mariabackup, dérivé de Percona XtraBackup, est un outil open source créé par MariaDB permettant d’effectuer des sauvegardes en ligne des tables InnoDB, MyRocks, Aria et MyISAM au format physique.
Options:
| --appliquer-journal | Prépare une sauvegarde récente pour la restauration du serveur MariaDB. |
| --appliquer-journal-uniquement | Effectuez uniquement l’étape d’application du journal de reprise. |
| --sauvegarde | Sauvegarde MariaDB. |
| --binlog-info | Spécifie la méthode permettant de récupérer les coordonnées du journal binaire depuis le serveur. |
| --fermer-fichiers | Détermine s’il faut fermer les descripteurs de fichiers ou non. |
| --compress | Définit la compression du fichier de sauvegarde. |
| --compress-chunk-size | Spécifie la taille du tampon de travail pour les threads de compression. |
| --compress-threads | Spécifie le nombre de threads de compression. |
| --copier-en-arrière | Restaure la sauvegarde dans le répertoire de données. |
| --bases-de-données | Détermine les bases de données et les tables à sauvegarder. |
Remarque: rendez-vous sur la page des options Mariabackup pour en savoir plus.
Fonctionnalités:
Configure une réplique à partir d’une sauvegarde.
Utilise des outils de chiffrement et de compression.
Restaure des tables et des partitions individuelles.
Prend en charge la méthode SST avec le cluster Glaera.
Prend en charge les sauvegardes et restaurations complètes, partielles et incrémentales.
Sauvegardes et restaurations de tables à l’aide du chiffrement des données au repos, du moteur de stockage MyRocks et de la compression de pages InnoDB.
Réduit au minimum les verrous pendant la sauvegarde et fournit une assistance optimale pour la sauvegarde de tous les moteurs de stockage de MariaDB Enterprise Backup.
Avantages:
Open source et gratuit à utiliser.
Assure un haut niveau de cohérence et d’intégrité des données.
Facile à installer et à utiliser, avec une documentation claire et une interface conviviale.
Conçu spécifiquement pour MariaDB, il est optimisé pour ce système de gestion de base de données particulier.
Inconvénients:
Prend uniquement en charge les opérations de sauvegarde et de restauration pour MariaDB.
Ne prend pas en charge le chiffrement basé sur les outils de sauvegarde ni l’option de compactage.
Nécessite quelques connaissances des interfaces en ligne de commande et des procédures de sauvegarde.
Ne prend pas en charge la compression ni le chiffrement des données au repos pour les sauvegardes complètes.
Ne prend pas en charge la sauvegarde partielle des données MyRocks et la sauvegarde incrémentale enregistrera une copie complète.
Peut ne pas convenir aux très grandes bases de données ou aux opérations de sauvegarde devant être effectuées fréquemment, car cela peut consommer une quantité importante de ressources système.
Faites attention à ne pas inclure de fautes de frappe ni à utiliser des options provenant de versions plus récentes de Mariabackup, car le logiciel ignore les options de ligne de commande inconnues sans afficher de message d’erreur.
Installer Mariabackup
Sous Linux:
Installez-le à l’aide d’un gestionnaire de paquets et exécutez-le en tant que root :
curl -LsS https://r.mariadb.com/downloads/mariadb_repo_setup | sudo bash
Installer avec yum/dnf pour RHEL, CentOS, Fedora et d’autres distributions Linux similaires :
sudo yum install MariaDB-backup
Installez avec apt-get pour Debian, Ubuntu et d’autres distributions Linux similaires :
sudo apt-get install mariadb-backup
Installation avec zip pour SLES, OpenSUSE et d'autres distributions Linux similaires :
sudo zypper install MariaDB-backup
Sous Windows:
1. Installez le package MSI de MariaDB.
2. Cliquez sur le fichier mariadb-<major>.<minor>.<patch>.msi.
3. Cliquez sur Suivant sur la page d’accueil, acceptez le contrat de licence, puis cliquez sur Suivant.
4. Sur la page Installation personnalisée, cliquez sur Utilitaires de sauvegarde pour les installer.
5. Suivez l’assistant.
Sauvegarder et restaurer MariaDB avec Mariabackup
Sauvegarder l’ensemble du serveur de base de données:
$ mariabackup --backup --target-dir=/var/mariadb/backup/ --utilisateur=mariabackup --motdepasse=mypassword
Effectuez une sauvegarde incrémentale (créez d’abord une sauvegarde complète):
$ mariabackup --backup --target-dir=/var/mariadb/inc1/ --incremental-basedir=/var/mariadb/backup/ --utilisateur=mariabackup --motdepasse=mypassword
Préparez des sauvegardes cohérentes pour la restauration:
$ mariabackup --prepare --target-dir=/var/mariadb/backup/
Restaurer la base de données complète:
a. Arrêtez le processus du serveur et assurez-vous que le répertoire « datadir » est vide.
b. Exécutez l’option –copy-back pour conserver les fichiers de sauvegarde d’origine, ou l’option –move-back pour déplacer les données vers le répertoire datadir, auquel cas les fichiers d’origine sont perdus.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
c. Démarrer le processus du serveur MariaDB.
Restaurez les modifications contenues dans la première sauvegarde incrémentale, puis répétez cette étape pour chacune des sauvegardes restantes avec MariaDB 10.2 :
a. Préparez la sauvegarde complète de base.
$ mariabackup --prepare --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
b. Mettre la base à jour pour refléter les modifications.
$ mariabackup --prepare --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Arrêtez le processus du serveur et assurez-vous que le répertoire « datadir » est vide.
d. Exécutez l’option –copy-back pour conserver les fichiers de sauvegarde d’origine, ou l’option –move-back pour déplacer les données vers le répertoire datadir, auquel cas les fichiers d’origine sont supprimés.
$ mariabackup --copier-les-données --target-dir=/var/mariadb/backup/
Restaurer une sauvegarde incrémentale avec MariaDB jusqu’à la version 10.1:
a. Préparez la sauvegarde complète de base.
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup
b. Appliquer les augmentations à la base:
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Arrêtez le processus du serveur et assurez-vous que le répertoire « datadir » est vide.
d. Exécutez l’option –copy-back pour conserver les fichiers de sauvegarde d’origine, ou l’option –move-back pour déplacer les données vers le répertoire datadir (les fichiers d’origine seront alors perdus).
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
Sauvegarde et restauration de MariaDB avec mysqldump
Mysqldump est un outil de sauvegarde intégré à MariaDB permettant d’exporter une ou plusieurs bases de données au format CSV, autre format texte délimité ou XML, dans un but de sauvegarde ou de transfert. Il peut également être utilisé pour sauvegarder et restaurer MySQL.
Exporter toutes les bases de données MariaDB:
mysqldump -u xx -p -x -A > /data/backup/dbs.sql
Exporter plusieurs bases de données ou toutes les bases de données:
shell> mysqldump --databases db_name1 [db_name2 ...] > my_databases.sql shell> mysqldump --all-databases > all_databases.sql
Sauvegarder l’intégralité de la base de données:
shell> mysqldump db_name > backup-file.sql
Sauvegarder une seule base de données:
mysqldump --user=xx --password --lock-tables --databases db1 > /data/backup/db1.sql
Sauvegarder une table:
mysqldump --user=xx --password --lock-tables db1 table1 > /data/backup/db1_table1.sql
Restaurer une sauvegarde:
mysql -u root -p < backup-file.sql
Sauvegarde et restauration de MariaDB avec une solution de sauvegarde de bases de données
Quelle que soit la méthode choisie, les procédures de sauvegarde et de restauration de MariaDB sont loin d’être intuitives ou conviviales pour un débutant. Essayez Vinchin Backup & Recovery, compatible avec 12 environnements de virtualisation tels que VMware, Hyper-V, Xen, RHEV/oVirt, etc., 2 serveurs physiques, des NAS et 6 bases de données, notamment Oracle DB, MySQL, SQL Server, PostgreSQL, Postgres Pro et MariaDB.

Vous pouvez automatiser la sauvegarde de votre base de données à l’aide de plannings personnalisés et choisir, en un seul clic, entre les sauvegardes complètes, différentielles, incrémentales et des journaux (selon le type de base de données).
Vous pouvez activer la déduplication et la compression des données afin de réduire la taille globale des sauvegardes, et activer le chiffrement des données selon la norme AES-256 pour renforcer la sécurité.
Restaurez MariaDB vers la base de données d’origine ou vers une nouvelle base de destination, et préparez une copie de sauvegarde hors site dans un emplacement distant.
Téléchargez dès maintenant l’essai gratuit de 60 jours de la nouvelle version 7.0 :
Processus de sauvegarde MariaDB simplifié :
1. Accédez à Sauvegarde physique > Sauvegarde de base de données > Sauvegarde, puis sélectionnez l’agent de sauvegarde de base de données installé ainsi que la source de sauvegarde.
2. Sélectionnez le nœud de sauvegarde et le stockage sur ce nœud pour la tâche.
3. Préciser les stratégies de sauvegarde selon les besoins.

4. Confirmez et envoyez.
Processus simple de restauration de MariaDB
1. Accédez à Physical Backup > Database Backup > Restore, puis sélectionnez la ressource à restaurer parmi les sauvegardes de bases de données.
2. Sélectionnez l'instance cible.
3. Choisissez de restaurer vers l'emplacement d'origine ou vers une nouvelle destination, puis définissez la stratégie de restauration.

4. Vérifiez les paramètres, puis confirmez et lancez la restauration.
Conclusion
Vous pouvez sauvegarder et restaurer MariaDB avec Mariabackup et Mysqldump, mais ces outils ne proposent ni une interface graphique intuitive ni la variété d'options de sauvegarde offertes par Vinchin Backup & Recovery, une solution professionnelle de sauvegarde de bases de données. Cette solution automatise les opérations de sauvegarde et de restauration, tout en intégrant des technologies avancées de protection contre les logiciels malveillants afin d'assurer une protection complète de vos données MariaDB.
Partager sur :